scoretools.FixedDurationTuplet
==============================

.. abjad-lineage:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet

.. autoclass:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.append
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.extend
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.force_fraction
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.from_duration_and_ratio
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.from_leaf_and_ratio
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.from_nonreduced_ratio_and_nonreduced_fraction
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.implied_prolation
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.index
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.insert
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_augmentation
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_diminution
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_invisible
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_simultaneous
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_trivial
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.multiplied_duration
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.multiplier
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.pop
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.preferred_denominator
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.remove
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.reverse
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.select_leaves
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.select_notes_and_chords
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.set_minimum_denominator
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.target_duration
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.to_fixed_duration_tuplet
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.to_fixed_multiplier
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.toggle_prolation
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.trim
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__contains__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__copy__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__delitem__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__eq__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__format__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__getitem__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__hash__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__illustrate__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__len__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__mul__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__ne__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__repr__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__rmul__
      ~abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__setitem__

Bases
-----

- :py:class:`scoretools.Tuplet <abjad.tools.scoretools.Tuplet.Tuplet>`

- :py:class:`scoretools.Container <abjad.tools.scoretools.Container.Container>`

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_augmentation
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_diminution
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_trivial
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.multiplied_duration
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.force_fraction
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_invisible
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.is_simultaneous
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.multiplier
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.preferred_denominator
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.target_duration
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.append
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.index
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.select_leaves
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.select_notes_and_chords
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.set_minimum_denominator
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.to_fixed_duration_tuplet
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.to_fixed_multiplier
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.toggle_prolation
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.trim
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.from_duration_and_ratio
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.from_leaf_and_ratio
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.from_nonreduced_ratio_and_nonreduced_fraction
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__hash__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationTuplet.FixedDurationTuplet.__setitem__
   :noindex:
